==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/GridBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { NativeUIElementBridge } from "./NativeUIElementBridge";
import { INativeUIGridBridge_$type } from "./INativeUIGridBridge";
import { List$1 } from "./List$1";
import { NativeUIComponent } from "./NativeUIComponent";
import { GridBridgeColumnDefinition } from "./GridBridgeColumnDefinition";
import { GridBridgeRowDefinition } from "./GridBridgeRowDefinition";
import { markType } from "./type";
/**
 * @hidden
 */
export let GridBridge = /*@__PURE__*/ (() => {
    class GridBridge extends NativeUIElementBridge {
        constructor() {
            super();
            this.e = null;
            this.c = new List$1(GridBridgeColumnDefinition.$, 0);
            this.d = new List$1(GridBridgeRowDefinition.$, 0);
            this.e = new List$1(NativeUIComponent.$, 0);
        }
        addChild(a, b) {
            this.e.add(b);
            a.append(b.u);
        }
        addColumnDefinition(a, b, c, d) {
            let e = new GridBridgeColumnDefinition();
            e.a = c;
            e.b = d;
            this.c.add(e);
            this.f(a);
        }
        f(a) {
            let b = "";
            for (let c = 0; c < this.c.count; c++) {
                if (c > 0) {
                    b += " ";
                }
                b += this.c._inner[c].c();
            }
            a.setStyleProperty("grid-template-columns", b);
        }
        g(a) {
            let b = "";
            for (let c = 0; c < this.d.count; c++) {
                if (c > 0) {
                    b += " ";
                }
                b += this.d._inner[c].c();
            }
            a.setStyleProperty("grid-template-rows", b);
        }
        addHandler(a, b, c, d) {
        }
        addRowDefinition(a, b, c, d) {
            let e = new GridBridgeRowDefinition();
            e.a = c;
            e.b = d;
            this.d.add(e);
            this.g(a);
        }
        getChildAt(a, b) {
            return this.e._inner[b];
        }
        getChildrenCount(a) {
            return a.getChildCount();
        }
        getColumn(a, b) {
            let c = b.u.getStyleProperty("grid-column");
            let d = parseInt(c);
            return d - 1;
        }
        getColumnDefinitionsCount(a) {
            return this.c.count;
        }
        getRow(a, b) {
            let c = b.u.getStyleProperty("grid-row");
            let d = parseInt(c);
            return d - 1;
        }
        getRowDefinitionsCount(a) {
            return this.d.count;
        }
        getValue(a, b) {
            switch (b) {
            }
            return null;
        }
        removeChild(a, b) {
            this.e.remove(b);
            a.removeChild(b.u);
        }
        removeChildAt(a, b) {
            this.e.removeAt(b);
            a.getChildAt(b).remove();
        }
        removeColumnDefinition(a, b) {
            this.c.removeAt(b);
            this.f(a);
        }
        removeHandler(a, b, c, d) {
        }
        removeRowDefinition(a, b) {
            this.d.removeAt(b);
            this.g(a);
        }
        setColumn(a, b, c) {
            b.u.setStyleProperty("grid-column", (c + 1).toString());
        }
        setRow(a, b, c) {
            b.u.setStyleProperty("grid-row", (c + 1).toString());
        }
        setValue(a, b, c) {
            switch (b) {
            }
        }
        updateColumnDefinition(a, b, c, d) {
            let e = this.c._inner[b];
            e.a = c;
            e.b = d;
            this.g(a);
        }
        updateRowDefinition(a, b, c, d) {
            let e = this.d._inner[b];
            e.a = c;
            e.b = d;
            this.g(a);
        }
    }
    GridBridge.$t = /*@__PURE__*/ markType(GridBridge, 'GridBridge', NativeUIElementBridge.$, [INativeUIGridBridge_$type]);
    return GridBridge;
})();

==> igniteui-react-core-18.1.3.tgz: package/esm2015/lib/GridBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PanelBridge } from "./PanelBridge";
import { INativeUIGridBridge_$type } from "./INativeUIGridBridge";
import { List$1 } from "./List$1";
import { GridBridgeColumnDefinition } from "./GridBridgeColumnDefinition";
import { GridBridgeRowDefinition } from "./GridBridgeRowDefinition";
import { markType } from "./type";
/**
 * @hidden
 */
export let GridBridge = /*@__PURE__*/ (() => {
    class GridBridge extends PanelBridge {
        constructor() {
            super();
            this.i = new List$1(GridBridgeColumnDefinition.$, 0);
            this.j = new List$1(GridBridgeRowDefinition.$, 0);
        }
        addColumnDefinition(a, b, c, d) {
            let e = new GridBridgeColumnDefinition();
            e.a = c;
            e.b = d;
            this.i.add(e);
            this.k(a);
        }
        k(a) {
            let b = "";
            for (let c = 0; c < this.i.count; c++) {
                if (c > 0) {
                    b += " ";
                }
                b += this.i._inner[c].c();
            }
            a.setStyleProperty("grid-template-columns", b);
        }
        l(a) {
            let b = "";
            for (let c = 0; c < this.j.count; c++) {
                if (c > 0) {
                    b += " ";
                }
                b += this.j._inner[c].c();
            }
            a.setStyleProperty("grid-template-rows", b);
        }
        addHandler(a, b, c, d) {
        }
        addRowDefinition(a, b, c, d) {
            let e = new GridBridgeRowDefinition();
            e.a = c;
            e.b = d;
            this.j.add(e);
            this.l(a);
        }
        getColumn(a, b) {
            let c = b.x.getStyleProperty("grid-column");
            let d = parseInt(c);
            return d - 1;
        }
        getColumnDefinitionsCount(a) {
            return this.i.count;
        }
        getRow(a, b) {
            let c = b.x.getStyleProperty("grid-row");
            let d = parseInt(c);
            return d - 1;
        }
        getRowDefinitionsCount(a) {
            return this.j.count;
        }
        getValue(a, b) {
            switch (b) {
            }
            return null;
        }
        removeColumnDefinition(a, b) {
            this.i.removeAt(b);
            this.k(a);
        }
        removeHandler(a, b, c, d) {
        }
        removeRowDefinition(a, b) {
            this.j.removeAt(b);
            this.l(a);
        }
        setColumn(a, b, c) {
            b.x.setStyleProperty("grid-column", (c + 1).toString());
        }
        setRow(a, b, c) {
            b.x.setStyleProperty("grid-row", (c + 1).toString());
        }
        setValue(a, b, c) {
            switch (b) {
            }
        }
        updateColumnDefinition(a, b, c, d) {
            let e = this.i._inner[b];
            e.a = c;
            e.b = d;
            this.l(a);
        }
        updateRowDefinition(a, b, c, d) {
            let e = this.j._inner[b];
            e.a = c;
            e.b = d;
            this.l(a);
        }
        getChildAt(a, b) {
            return this.c.apply(this, arguments);
        }
        removeChildAt(a, b) {
            this.h.apply(this, arguments);
        }
        addChild(a, b) {
            this.f.apply(this, arguments);
        }
        removeChild(a, b) {
            this.g.apply(this, arguments);
        }
        getChildrenCount(a) {
            return this.e.apply(this, arguments);
        }
    }
    GridBridge.$t = /*@__PURE__*/ markType(GridBridge, 'GridBridge', PanelBridge.$, [INativeUIGridBridge_$type]);
    return GridBridge;
})();
